==> laptop-mode-tools_1.05.orig.tar.gz: laptop-mode-tools-1.05/etc/acpi/actions/lm_battery.sh <==
#! /bin/bash

test -f /usr/sbin/laptop_mode || exit 0

# Automatically disable laptop mode when the battery almost runs out.

BATT_INFO=/proc/acpi/battery/$2/state

MINIMUM_BATTERY_MINUTES=7
ACPI_WITHOUT_AC_EVENTS=0

. /usr/sbin/laptop_mode defaults
if [ -f /etc/laptop-mode/laptop-mode.conf ] ; then
	. /etc/laptop-mode/laptop-mode.conf
fi

if [ $ACPI_WITHOUT_AC_EVENTS -ne 0 ] ; then
	/etc/acpi/actions/lm_ac_adapter.sh
fi

if [ -f /proc/sys/vm/laptop_mode ]
then
   LM=`cat /proc/sys/vm/laptop_mode`
   if [ $LM -gt 0 ] ; then
     if [ -f $BATT_INFO ] ; then
        ACTION="`cat $BATT_INFO | grep charging | cut -c 26-`"
	REMAINING=`cat $BATT_INFO | grep "remaining capacity:" | sed  "s/.* \([0-9][0-9]* \).*/\1/" `
	IN_MAH=0
	IN_MWH=0
	if ( cat $BATT_INFO | grep mWh ) ; then
		IN_MWH=1
	elif ( cat $BATT_INFO | grep mAh ) ; then
	        IN_MAH=1
	fi
	DO=0
        if [ "$ACTION" == "discharging" ] ; then
		PRESENT_RATE=`cat $BATT_INFO | grep "present rate:" | sed  "s/.* \([0-9][0-9]* \).*/\1/" `
		if [[ $PRESENT_RATE -ne 0 ]] ; then
			if (($REMAINING * 60 / $PRESENT_RATE < $MINIMUM_BATTERY_MINUTES))
			then
				DO=1
			fi
		fi
	fi
	if [ "$IN_MAH" -ne 0 -a "$REMAINING" -lt "$MINIMUM_BATTERY_CHARGE_MAH" ] ; then
		DO=1
	fi
	if [ "$IN_MWH" -ne 0 -a "$REMAINING" -lt "$MINIMUM_BATTERY_CHARGE_MWH" ] ; then
		DO=1
	fi
	if [ $DO -ne 0 ] ; then
		/usr/sbin/laptop_mode stop
	fi
     else
        logger -p daemon.warning "You are using laptop mode and your battery interface $BATT_INFO is missing. This may lead to loss of data when the battery runs out. Check kernel ACPI support and /proc/acpi/battery folder, and edit /etc/acpi/lm_battery.sh to set BATT_INFO to the correct path."
     fi
   fi
fi

==> laptop-mode-tools_1.11.orig.tar.gz: laptop-mode-tools-1.11/etc/acpi/actions/lm_battery.sh <==
#! /bin/bash

test -f /usr/sbin/laptop_mode || exit 0

# Automatically disable laptop mode when the battery almost runs out.

BATT_INFO=/proc/acpi/battery/$2/state

MINIMUM_BATTERY_MINUTES=7
ACPI_WITHOUT_AC_EVENTS=0

. /usr/sbin/laptop_mode readconfig

if [ $ACPI_WITHOUT_AC_EVENTS -ne 0 ] ; then
	/etc/acpi/actions/lm_ac_adapter.sh
fi

if [ -f /proc/sys/vm/laptop_mode ]
then
   LM=`cat /proc/sys/vm/laptop_mode`
   if [ $LM -gt 0 ] ; then
     if [ -f $BATT_INFO ] ; then
        ACTION="`cat $BATT_INFO | grep charging | cut -c 26-`"
	REMAINING=`cat $BATT_INFO | grep "remaining capacity:" | sed  "s/.* \([0-9][0-9]* \).*/\1/" `
	IN_MAH=0
	IN_MWH=0
	if ( cat $BATT_INFO | grep mWh ) ; then
		IN_MWH=1
	elif ( cat $BATT_INFO | grep mAh ) ; then
	        IN_MAH=1
	fi
	DO=0
        if [ "$ACTION" == "discharging" ] ; then
		PRESENT_RATE=`cat $BATT_INFO | grep "present rate:" | sed  "s/.* \([0-9][0-9]* \).*/\1/" `
		if [[ $PRESENT_RATE -ne 0 ]] ; then
			if (($REMAINING * 60 / $PRESENT_RATE < $MINIMUM_BATTERY_MINUTES))
			then
				DO=1
			fi
		fi
	fi
	if [ "$IN_MAH" -ne 0 -a "$REMAINING" -lt "$MINIMUM_BATTERY_CHARGE_MAH" ] ; then
		DO=1
	fi
	if [ "$IN_MWH" -ne 0 -a "$REMAINING" -lt "$MINIMUM_BATTERY_CHARGE_MWH" ] ; then
		DO=1
	fi
	if [ $DO -ne 0 ] ; then
		/usr/sbin/laptop_mode stop
	fi
     else
        logger -p daemon.warning "You are using laptop mode and your battery interface $BATT_INFO is missing. This may lead to loss of data when the battery runs out. Check kernel ACPI support and /proc/acpi/battery folder, and edit /etc/acpi/lm_battery.sh to set BATT_INFO to the correct path."
     fi
   fi
fi
